@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 extends 'Zing::Entity';
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 # ATTRIBUTES
 
@@ -78,6 +78,10 @@ method next() {
 
     delete $self->{prev_null};
 
+    if (!$position) {
+      return undef;
+    }
+
     my $current = $self->lookup->state->{$position} or return undef;
 
     $self->position($position);
@@ -85,6 +89,10 @@ method next() {
     return $self->app->domain(name => $current->{name});
   }
 
+  if (!$position) {
+    return undef;
+  }
+
   my $current = $self->lookup->state->{$position} or return undef;
 
   if (!$current->{next}) {
@@ -114,6 +122,10 @@ method prev() {
 
     delete $self->{next_null};
 
+    if (!$position) {
+      return undef;
+    }
+
     my $current = $self->lookup->state->{$position} or return undef;
 
     $self->position($position);
@@ -121,6 +133,10 @@ method prev() {
     return $self->app->domain(name => $current->{name});
   }
 
+  if (!$position) {
+    return undef;
+  }
+
   my $current = $self->lookup->state->{$position} or return undef;
 
   if (!$current->{prev}) {
